InitializeResponse class

Response model for SDK initialization operation.

This provides type-safe access to initialization results.

Inheritance

Constructors

InitializeResponse({required bool result, required String errorMessage})
Creates an InitializeResponse instance.
const
InitializeResponse.fromJson(Map<String, dynamic> json)
Creates an InitializeResponse from a JSON map.
factory

Properties

errorMessage String
Error message if the operation failed, empty string if successful.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
result bool
Whether the operation was successful.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the response to a JSON map.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited