ArtifactsModel class

Constructors

ArtifactsModel({required String ocrFaceImage, required String backSideImage, required String frontSideImage, String? activeLivenessImage, String? passiveLiveNessImage, required String nfcFaceImage})
const
ArtifactsModel.fromJson(Map<String, dynamic> json)
factory

Properties

activeLivenessImage String?
final
backSideImage String
final
frontSideImage String
final
hashCode int
The hash code for this object.
no setterinherited
nfcFaceImage String
final
ocrFaceImage String
final
passiveLiveNessImage String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited