FaceMatching class

Constructors

FaceMatching({required String notes, required bool isSuccessful, required int matchingScore, required int thresholdUsed})
const
FaceMatching.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isSuccessful bool
final
matchingScore int
final
notes String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thresholdUsed int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited