ScanData class

Constructors

ScanData({VerificationResultData? data, required String message, required String consolidatedMessage, String? errorMessage})
const
ScanData.fromJson(Map<String, dynamic> json)
factory

Properties

consolidatedMessage String
final
data VerificationResultData?
final
errorMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited