ScanDataModel class

Constructors

ScanDataModel({required String gender, required String country, required String mrzText, required String fullName, required String documentNo, required String expiryDate, required String nationality, required String dateOfBirth, required String documentType, String cardNumber = ''})
const
ScanDataModel.fromJson(Map<String, dynamic> json)
factory

Properties

cardNumber String
final
country String
final
dateOfBirth String
final
documentNo String
final
documentType String
final
expiryDate String
final
fullName String
final
gender String
final
hashCode int
The hash code for this object.
no setterinherited
mrzText String
final
nationality String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited