VerificationDetails class

Constructors

VerificationDetails({ScanDataModel? scan, LivenessDataModel? liveness, NFCDataModel? nfc, SubmitVerificationBarcode? barcode})
const
VerificationDetails.fromJson(Map<String, dynamic> json)
factory

Properties

barcode SubmitVerificationBarcode?
final
hashCode int
The hash code for this object.
no setterinherited
liveness LivenessDataModel?
final
nfc NFCDataModel?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scan ScanDataModel?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited