VerificationResultData class

Constructors

VerificationResultData({required String id, required VerificationDetails data, required MetaDataModel metaData, required ArtifactsModel artifacts, required AnnotationModel annotation, required VerificationTypeModel type, required VerificationStatusModel status, List<String>? statusNotes})
const
VerificationResultData.fromJson(Map<String, dynamic> json)
factory

Properties

annotation AnnotationModel
final
artifacts ArtifactsModel
final
data VerificationDetails
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
metaData MetaDataModel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status VerificationStatusModel
final
statusNotes List<String>?
final
type VerificationTypeModel
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited