FeatureFlagsUsed class
Constructors
- FeatureFlagsUsed({required bool malaaConsentGiven, required bool isMala2aaCheckEnabled, required bool isMala2aaCheckConsentOptional, required bool showInstructions, required bool isOcrEnabled, required bool isMrzEnabled, required bool isNfcScanningEnabled, bool? isNfcSkippable, bool? nfcCountCancelRetry, required String nfcMaximumRetries, required bool isPassiveLivenessEnabled, required bool isActiveLivenessEnabled, required bool isFaceMatchingEnabled})
-
const
-
FeatureFlagsUsed.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActiveLivenessEnabled → bool
-
final
- isFaceMatchingEnabled → bool
-
final
- isMala2aaCheckConsentOptional → bool
-
final
- isMala2aaCheckEnabled → bool
-
final
- isMrzEnabled → bool
-
final
- isNfcScanningEnabled → bool
-
final
- isNfcSkippable → bool?
-
final
- isOcrEnabled → bool
-
final
- isPassiveLivenessEnabled → bool
-
final
- malaaConsentGiven → bool
-
final
- nfcCountCancelRetry → bool?
-
final
- nfcMaximumRetries → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showInstructions → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited