MetaDataModel class
Constructors
-
MetaDataModel({String? gender, required Location location, String? networkType, bool? vpnUsed, String? deviceIp4, String? deviceIp6, required String deviceType, required String deviceIdentifier, required String deviceId, required String systemName, required String systemVersion, required String appVersion, String? sdkVersion, required String timestamp, required FeatureFlagsUsed ffUsed, Map<
String, dynamic> ? extraData}) -
const
-
MetaDataModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- appVersion → String
-
final
- deviceId → String
-
final
- deviceIdentifier → String
-
final
- deviceIp4 → String?
-
final
- deviceIp6 → String?
-
final
- deviceType → String
-
final
-
extraData
→ Map<
String, dynamic> ? -
final
- ffUsed → FeatureFlagsUsed
-
final
- gender → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- location → Location
-
final
- networkType → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sdkVersion → String?
-
final
- systemName → String
-
final
- systemVersion → String
-
final
- timestamp → String
-
final
- vpnUsed → bool?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited