SdkResponse class abstract
Base class for all SDK operation responses.
All SDK responses extend this class to provide consistent structure and type safety across the SDK.
Constructors
- SdkResponse({required bool result, required String errorMessage})
-
Creates an SdkResponse instance.
const
-
SdkResponse.fromJson(Map<
String, dynamic> json) -
Creates an SdkResponse from a JSON map.
factory
Properties
- errorMessage → String
-
Error message if the operation failed, empty string if successful.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- result → bool
-
Whether the operation was successful.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts the response to a JSON map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited