SdkResponseImpl class
Default implementation of SdkResponse.
- Inheritance
-
- Object
- SdkResponse
- SdkResponseImpl
Constructors
- SdkResponseImpl({required bool result, required String errorMessage})
-
const
Properties
- errorMessage → String
-
Error message if the operation failed, empty string if successful.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- result → bool
-
Whether the operation was successful.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the response to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited