VerificationResponse class
Response model for SDK verification operation.
This provides type-safe access to verification results.
- Inheritance
-
- Object
- SdkResponse
- VerificationResponse
Constructors
- VerificationResponse({required bool result, required String errorMessage, required String verificationID})
-
Creates a VerificationResponse instance.
const
-
VerificationResponse.fromJson(Map<
String, dynamic> json) -
Creates a VerificationResponse from a JSON map.
factory
Properties
- errorMessage → String
-
Error message if the operation failed, empty string if successful.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasVerificationID → bool
-
Whether a verification ID is available.
no setter
- isFailure → bool
-
Whether verification failed.
no setter
- isSuccess → bool
-
Whether verification was successful.
no setter
- result → bool
-
Whether the operation was successful.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verificationID → String
-
The verification ID returned after successful verification.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the response to a JSON map.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited