VerificationResultResponse class
Response model for SDK getVerificationResult operation.
This provides type-safe access to verification result data.
- Inheritance
-
- Object
- SdkResponse
- VerificationResultResponse
Constructors
- VerificationResultResponse({required bool result, required String errorMessage, ScanData? scanData})
-
Creates a VerificationResultResponse instance.
const
-
VerificationResultResponse.fromJson(Map<
String, dynamic> json) -
Creates a VerificationResultResponse from a JSON map.
factory
Properties
- errorMessage → String
-
Error message if the operation failed, empty string if successful.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasScanData → bool
-
Whether scan data is available.
no setter
- isFailure → bool
-
Whether verification result retrieval failed.
no setter
- isSuccess → bool
-
Whether verification result was retrieved successfully.
no setter
- result → bool
-
Whether the operation was successful.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scanData → ScanData?
-
The scan data containing verification details.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the response to a JSON map.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited